from django.conf import settings


def get_email_variables():
    try:
        public_key = settings.MALLGO_PUBLIC_KEY
        private_key = settings.MALLGO_PRIVATE_KEY
    except AttributeError:
        print('MALLGO_PUBLIC_KEY and MALLGO_PRIVATE_KEY are not defined in settings.py')
        public_key = None
        private_key = None
    return {
        'public_key': public_key,
        'private_key': private_key,
    }



import requests
import logging

logger = logging.getLogger(__name__)


def send_email(data, auth_key):
    if auth_key is None:
        logger.error('MALLGO_AUTH_KEY is not defined in settings.py')
        return False
    body = {
        'from_email': data['from_email'],
        'reply_to': data['reply_to'],
        'to_email': data['to'],
        'cc_email': data.get('cc', []),
        'bcc_email': data.get('bcc', []),
        'subject': data.get('subject', None),
        'body': data.get('body', None)
    }
    if 'template' in data:
        body['template'] = data.get('template', None)
        body['template_vars'] = data.get('template_vars', {})
    url = 'https://api.email.mallgo.co/send-email/'
    headers = {
        'Content-Type': 'application/json',
        'Authorization': auth_key
    }
    response = requests.post(url, json=body, headers=headers)
    logger.debug(response.content)
    if response.status_code != 200:
        logger.error("MallGo could not send the email, endpoint response: %s" % response.content)
        body['result'] = response.content
        return body
    logger.debug("Email sent successfully %s" % response.content)
    answer = response.json()
    body['result'] = answer
    return body



from django.core.mail import EmailMessage


class MallGoEmailMessage(EmailMessage):
    def __init__(self, *args, template=None, template_vars={}, **kwargs):
        self.connection = None
        self.template = template
        self.template_vars = template_vars
        super().__init__(*args, **kwargs)

    def send(self, fail_silently=False):
        from MallGoEmail.backend import MallGoEmailBackend
        if not self.connection:
            self.connection = MallGoEmailBackend(fail_silently=fail_silently)
        return self.connection.send_messages([self])
